local PlayerState = require 'entities/player/PlayerState'

local PlayerPhysics = {}

function PlayerPhysics:load()
  PlayerPhysics.wheel = {}
    PlayerPhysics.wheel.body = love.physics.newBody( world, ( PlayerState.coordinates.wheelX ),( PlayerState.coordinates.wheelY ), 'dynamic' )
    PlayerPhysics.wheel.body:setFixedRotation( true )
    PlayerPhysics.wheel.shape = love.physics.newCircleShape( 45 )
    PlayerPhysics.wheel.fixture = love.physics.newFixture( PlayerPhysics.wheel.body,PlayerPhysics.wheel.shape )
    PlayerPhysics.wheel.fixture:setCategory( 2 )
    -- remove sensor??
  PlayerPhysics.wheelSensor = {}
    PlayerPhysics.wheelSensor.body = love.physics.newBody( world, ( PlayerState.coordinates.wheelSensorX ),( PlayerState.coordinates.wheelSensorY ), 'dynamic' )
    PlayerPhysics.wheelSensor.body:setFixedRotation( true )
    PlayerPhysics.wheelSensor.shape = love.physics.newCircleShape( 50 )
    PlayerPhysics.wheelSensor.fixture = love.physics.newFixture( PlayerPhysics.wheelSensor.body,PlayerPhysics.wheelSensor.shape )
    PlayerPhysics.wheelSensor.fixture:setSensor( true )
    PlayerPhysics.wheelSensor.fixture:setCategory( 3 )

  PlayerPhysics.lowerTorso = {}
    PlayerPhysics.lowerTorso.body = love.physics.newBody( world, ( PlayerState.coordinates.lowerTorsoX ),( PlayerState.coordinates.lowerTorsoY ), 'dynamic' )
    PlayerPhysics.lowerTorso.shape = love.physics.newPolygonShape( -50,0, 50,0, 35,-35, 25,-40, 15,-45, -15,-45, -25,-40, -35,-35 )
    PlayerPhysics.lowerTorso.fixture = love.physics.newFixture( PlayerPhysics.lowerTorso.body,PlayerPhysics.lowerTorso.shape )
    PlayerPhysics.lowerTorso.fixture:setCategory( 4 )

  PlayerPhysics.upperTorso = {}
    PlayerPhysics.upperTorso.body = love.physics.newBody( world, ( PlayerState.coordinates.upperTorsoX ),( PlayerState.coordinates.upperTorsoY ), 'dynamic' )
    PlayerPhysics.upperTorso.body:setLinearVelocity( 0,100 )
    PlayerPhysics.upperTorso.shape = love.physics.newPolygonShape( -35,0, -5,40, 5,40, 35,0, 50,-50, -50,-50 )
    PlayerPhysics.upperTorso.fixture = love.physics.newFixture( PlayerPhysics.upperTorso.body,PlayerPhysics.upperTorso.shape )
    PlayerPhysics.upperTorso.fixture:setCategory( 5 )

  PlayerPhysics.head = {}
    PlayerPhysics.head.body = love.physics.newBody( world, ( PlayerState.coordinates.headX ),( PlayerState.coordinates.headY ), 'dynamic' )
    PlayerPhysics.head.shape = love.physics.newCircleShape( 40 )
    PlayerPhysics.head.fixture = love.physics.newFixture( PlayerPhysics.head.body,PlayerPhysics.head.shape )
    PlayerPhysics.head.fixture:setCategory( 5 )
  PlayerPhysics.headSensor = {}
    PlayerPhysics.headSensor.body = love.physics.newBody( world, ( PlayerState.coordinates.headX ),( PlayerState.coordinates.headY ), 'dynamic' )
    PlayerPhysics.headSensor.shape = love.physics.newCircleShape( 55 )
    PlayerPhysics.headSensor.fixture = love.physics.newFixture( PlayerPhysics.headSensor.body,PlayerPhysics.headSensor.shape )
    PlayerPhysics.headSensor.fixture:setCategory( 3 )
    PlayerPhysics.headSensor.fixture:setSensor( true )

  PlayerPhysics.wheelWithinWheel =
  love.physics.newRopeJoint( PlayerPhysics.wheelSensor.body, PlayerPhysics.lowerTorso.body,
  ( PlayerPhysics.wheelSensor.body:getX() ),( PlayerPhysics.wheelSensor.body:getY() ),
  ( PlayerPhysics.lowerTorso.body:getX() ),( PlayerPhysics.lowerTorso.body:getY() ),
  50, false )
  PlayerPhysics.wheelWeld =
  love.physics.newWeldJoint( PlayerPhysics.wheel.body, PlayerPhysics.lowerTorso.body,
  ( PlayerPhysics.wheel.body:getX() ),( PlayerPhysics.wheel.body:getY() ),
  ( PlayerPhysics.lowerTorso.body:getX() ),( PlayerPhysics.lowerTorso.body:getY() ),
  false )

  PlayerPhysics.wheelUTRope =
  love.physics.newRopeJoint( PlayerPhysics.wheel.body, PlayerPhysics.upperTorso.body,
  ( PlayerPhysics.wheel.body:getX() ),( PlayerPhysics.wheel.body:getY() ),
  ( PlayerPhysics.upperTorso.body:getX() ),( PlayerPhysics.upperTorso.body:getY() ),
  130, true )

  PlayerPhysics.torsoWeld =
  love.physics.newWeldJoint( PlayerPhysics.lowerTorso.body, PlayerPhysics.upperTorso.body,
  ( PlayerPhysics.lowerTorso.body:getX() ),( PlayerPhysics.lowerTorso.body:getY() ),
  ( PlayerPhysics.upperTorso.body:getX() ),( PlayerPhysics.upperTorso.body:getY() + 60 ),
  false )

  PlayerPhysics.neckRope =
  love.physics.newRopeJoint( PlayerPhysics.upperTorso.body, PlayerPhysics.head.body,
  ( PlayerPhysics.upperTorso.body:getX() ),( PlayerPhysics.upperTorso.body:getY() - 40 ),
  ( PlayerPhysics.head.body:getX() ),( PlayerPhysics.head.body:getY() + 20 ),
  1, true )
  PlayerPhysics.headRope =
  love.physics.newRopeJoint( PlayerPhysics.head.body, PlayerPhysics.headSensor.body,
  ( PlayerPhysics.head.body:getX() ),( PlayerPhysics.head.body:getY() ),
  ( PlayerPhysics.headSensor.body:getX() ),( PlayerPhysics.headSensor.body:getY() ),
  55, false )
end

return PlayerPhysics
