
local RedWave = require 'entities/enemies/RedWave'
-- entities/enemies
local WorldPhysics = require 'entities/physics/WorldPhysics'
-- entities/level
local Level0 = require 'entities/levels/Level0'
-- entities/menu
local Menu = require 'entities/menu/Menu'
-- entities/player
local Input = require 'entities/player/Input'
local Player = require 'entities/player/Player'
local PlayerPhysics = require 'entities/player/PlayerPhysics'
local PlayerState = require 'entities/player/PlayerState'
-- libraries
local Camera = require 'libraries/camera'

-- CYBERlance

function love.load()
  WorldPhysics:load()
  RedWave:load()
  Level0:load()
  PlayerPhysics:load()
  playerCam1 = Camera( PlayerPhysics.headSensor.body:getX(),PlayerPhysics.headSensor.body:getY(), .4 )
  playerCam2 = Camera( PlayerPhysics.head.body:getX(),PlayerPhysics.head.body:getY(), .075 )

  canvas = love.graphics.newCanvas()
  local str = love.filesystem.read('entities/shaders/CRT-Simple.frag')
  CRT = love.graphics.newShader(str)
  CRT:send('inputSize', {love.graphics.getWidth(), love.graphics.getHeight()})
  CRT:send('textureSize', {love.graphics.getWidth(), love.graphics.getHeight()})

end

function love.update( dt )
  world:update( dt )
  Input:update( dt )
  playerCam1:lookAt( PlayerPhysics.headSensor.body:getX(),PlayerPhysics.headSensor.body:getY() )
  playerCam2:lookAt( PlayerPhysics.head.body:getX(),PlayerPhysics.head.body:getY() )
  --[[if isJumping == true then
    playerCam1:zoomTo( .35 )
  end
  if isJumping == false then
    playerCam1:zoomTo( .4 )
  end]]
  if gameStart == true then
    RedWave.physics.wave1.body:applyForce( 510,0 )
  end
  if gameStart == true then
    PlayerState.speed = 1000
  end
  if gameOver == true then
    PlayerState.speed = 0
  end
  if destroyPlayer == true then
    PlayerPhysics.head.body:applyLinearImpulse( 400,200 )
  end
end
function love.draw()


  love.graphics.setCanvas(canvas)

  if gameStart == true then
    playerCam2:attach()

    --love.graphics.setColor( 255, 255, 255, 50 )

    Level0:draw2()
    RedWave:draw2()
    Player:draw2()



    playerCam2:detach()
  end


  playerCam1:attach()


  Level0:draw1()
  RedWave:draw1()
  if gameStart == false then
    love.graphics.setColor( 10,50,10, 50 )
    Player:draw1()
  end
  if gameStart == true then
    Player:draw1()
  end

  if gameStart == false then
    love.graphics.setColor( 255,0,0 )
    love.graphics.polygon( 'fill', -100,50, 300,250, -100,400 )
    love.graphics.setColor( 255,255,255 )
    love.graphics.polygon( 'fill', -90,60, 310,260, -90,410 )



    love.graphics.setColor( 255,0,0 )
    love.graphics.print( 'enter', 400,200, 0, 10,10 )
    love.graphics.setColor( 255,255,255 )
    love.graphics.print( 'enter', 410,210, 0, 10,10 )

  end




  if gameOver == true then
    love.graphics.print( 'GAME OVER', 400,400, 0, 10,10 )
  end

  love.graphics.setColor( 0, 0, 0, 100 )

  playerCam1:detach()


  love.graphics.setColor( 25, 5, 5, 75 )
  if destroyPlayer == true then
    love.graphics.setColor( 200, 0, 0, 100 )
  end
  if gameWin == true then
    love.graphics.setColor( 0, 255, 0, 100 )
    love.graphics.print( 'win', 100,200, 0, 20,20 )
  end

  love.graphics.rectangle('fill', -100,-100, 2000, 2000)

  if gameOver == true then
    love.graphics.setColor( 200, 200, 200, 200 )
    love.graphics.print( 'game over', 20,300, 0, 18,15 )
  end

  love.graphics.setCanvas()

  love.graphics.setShader(CRT)

  love.graphics.draw(canvas)

-- momp
  love.graphics.print( 'go', 40,10, 0, 5,5 )

  if gameOver == true then
    love.graphics.setColor( 50, 10, 10, 50 )
    love.graphics.print( 'GAME OVER', 400,400, 0, 10,10 )

  end

  love.graphics.setShader()

  if gameOver == true then
    love.graphics.setColor( 200, 20, 20, 255 )
    love.graphics.print( 'GAME OVER', 400,410, 0, 10,10 )
  end


end
